# Contributor Covenant Code of Conduct

## 我们的承诺

为了营造一个开放和友好的环境，我们作为贡献者和维护者承诺：无论年龄、体型、残疾、民族、性别认同和表达、经验水平、教育程度、社会经济地位、国籍、个人形象、种族、宗教或性认同和性取向如何，都欢迎参与我们项目的每个人。

## 我们的标准

积极行为包括：

- 使用欢迎和包容的语言
- 尊重不同的观点和经验
- 优雅地接受建设性批评
- 关注对社区最有利的事情
- 对其他社区成员表示同理心

不可接受的行为包括：

- 使用性化的语言或图像，以及不受欢迎的性关注或性骚扰
- 恶意评论、侮辱/贬损评论、个人或政治攻击
- 公开或私下的骚扰
- 未经明确许可发布他人的私人信息，例如物理地址或电子邮件地址
- 在专业场合可能被合理认为不适当的其他行为

## 我们的责任

项目维护者有责任阐明可接受行为的标准，并应对任何不可接受的行为采取适当和公平的纠正措施。

项目维护者有权并有权删除、编辑或拒绝不符合本行为准则的评论、提交、代码、wiki 编辑、问题和其他贡献，并有权暂时或永久禁止任何他们认为行为不当、威胁、冒犯或有害的贡献者。

## 适用范围

本行为准则适用于所有项目空间，当个人代表项目或其社区时也适用于公共空间。代表项目或社区的示例包括使用官方项目电子邮件地址、通过官方社交媒体账户发布或在在线或离线活动中担任指定代表。项目维护者可以进一步阐明和澄清项目代表性。

## 执行

可以通过项目团队发送邮件至 [maintainer@example.com] 来报告滥用、骚扰或其他不可接受的行为。所有投诉都将被审查和调查，并将产生被认为必要且适合情况的回应。项目团队有义务对事件的报告者保密。具体执行政策的更多细节可能会单独发布。

不真诚地遵守或执行行为准则的项目维护者可能面临项目领导层确定的临时或永久后果。

## 归属

本行为准则改编自 [贡献者公约][homepage]，版本 1.4，
可在 https://www.contributor-covenant.org/version/1/4/code-of-conduct.html 查看

[homepage]: https://www.contributor-covenant.org

有关本行为准则的常见问题的答案，请参阅
https://www.contributor-covenant.org/faq